"use strict";

const get = require("lodash.get");

module.exports = {
    meta: {
        docs: {
            description: "Enforce the i18nKey prop value to contain namespace",
            category: "",
            recommended: true
        },
        schema: [
            {
                type: "object",
                properties: {
                    separator: {
                        type: "string"
                    }
                },
                additionalProperties: false
            }
        ]
    },

    create: context => {
        return {
            JSXOpeningElement: node => {
                const nodeType = node.name.name;
                const separator = get(context, "options.[0].separator", ":");

                if (nodeType !== "Trans") {
                    return;
                }

                const attrWithNoNS = node.attributes.find(
                    attr =>
                        attr.type === "JSXAttribute" &&
                        attr.name.name === "i18nKey" &&
                        attr.value &&
                        typeof attr.value.value === "string" &&
                        attr.value.value.split(separator).length < 2
                );

                if (attrWithNoNS) {
                    context.report(
                        node,
                        "The i18nKey prop value should have namespace"
                    );
                }
            }
        };
    }
};
